@@ -1,5 +1,5 @@
 package Net::Checkpoint::Management::v1;
-$Net::Checkpoint::Management::v1::VERSION = '0.001005';
+$Net::Checkpoint::Management::v1::VERSION = '0.001006';
 # ABSTRACT: Checkpoint Management API version 1.x client library
 
 use 5.024;
@@ -204,6 +204,17 @@ Net::Checkpoint::Management::v1::Role::ObjectMethods->apply([
         list_key => 'objects',
         id_keys  => [qw( uid name )],
     },
+    {
+        object   => 'groups',
+        singular => 'group',
+        create   => 'add-group',
+        list     => 'show-groups',
+        get      => 'show-group',
+        update   => 'set-group',
+        delete   => 'delete-group',
+        list_key => 'objects',
+        id_keys  => [qw( uid name )],
+    },
     {
         object   => 'access_roles',
         singular => 'access_role',
@@ -360,7 +371,7 @@ Net::Checkpoint::Management::v1 - Checkpoint Management API version 1.x client l
 
 =head1 VERSION
 
-version 0.001005
+version 0.001006
 
 =head1 SYNOPSIS
 
